@@ -152,8 +152,8 @@ get_code.uneval_model <- function(x, name = NULL, sub = FALSE,
     left_pad(paste0(
       name,
       "define_strategy(\n  ",
-      "transition_matrix = ",
-      get_code(x$transition_matrix, depth = depth),
+      "transition = ",
+      get_code(get_matrix(x), depth = depth),
       ",\n",
       st,
       "\n)"
@@ -206,9 +206,6 @@ get_code.run_model <- function(x, name = NULL, sub = FALSE,
       "method = ",
       paste0("\"", attr(x, "method"), "\"", sep = ""),
       ",\n  ",
-      "base_model = ",
-      paste0("\"", attr(x, "base_model"), "\"", sep = ""),
-      ",\n  ",
       "cost = ",
       deparse(attr(x, "ce")[[1]]$expr, width.cutoff = 500L),
       ",\n  ",
