@@ -170,6 +170,7 @@ eval_models_from_tabular <- function(inputs,
                                      run_demo = TRUE) {
   
   if (options()$heemod.verbose) message("* Running files...")
+  
   list_args <- c(
     inputs$models,
     list(
@@ -188,6 +189,11 @@ eval_models_from_tabular <- function(inputs,
     list_args
   )
   
+  
+  if (! is.null(inputs$model_options$num_cores)) {
+    use_cluster(inputs$model_options$num_cores)
+  }
+  
   if (options()$heemod.verbose) message("** Running models...")
   model_runs <- do.call(
     run_model,
@@ -202,7 +208,7 @@ eval_models_from_tabular <- function(inputs,
       inputs$param_info$dsa_params
     )
   }
-  
+
   model_psa <- NULL
   if (! is.null(inputs$param_info$psa_params) & run_psa) {
     if (options()$heemod.verbose) message("** Running PSA...")
@@ -212,13 +218,17 @@ eval_models_from_tabular <- function(inputs,
       N = inputs$model_options$n
     )
   }
-  
+
   demo_res <- NULL
   if (! is.null(inputs$demographic_file) & run_demo) {
     if (options()$heemod.verbose) message("** Running demographic analysis...")
     demo_res <- stats::update(model_runs, inputs$demographic_file)
   }
   
+  if(! is.null(inputs$model_options$num_cores)) {
+    close_cluster()
+  }
+  
   list(
     models = inputs$models,
     model_runs = model_runs,
@@ -576,7 +586,8 @@ create_parameters_from_tabular <- function(param_defs,
 create_options_from_tabular <- function(opt) {
   
   allowed_opt <- c("cost", "effect", "init",
-                   "method", "base", "cycles", "n")
+                   "method", "base", "cycles", "n",
+                   "num_cores")
   if(! inherits(opt, "data.frame"))
     stop("'opt' must be a data frame.")
   
@@ -618,7 +629,10 @@ create_options_from_tabular <- function(opt) {
   if (! is.null(res$effect)) {
     res$effect <- parse(text = res$effect)[[1]]
   }
-  if (options()$heemod.verbose) message(paste(
+  if (! is.null(res$num_cores)){
+    res$num_cores <- parse(text = res$num_cores)[[1]]
+  }
+    if (options()$heemod.verbose) message(paste(
     names(res), unlist(res), sep = " = ", collapse = "\n"
   ))
   res
@@ -655,7 +669,7 @@ create_model_from_tabular <- function(state_file,
   TM <- create_matrix_from_tabular(tm_file, get_state_names(states),
                                    df_env = df_env)
   
-  define_strategy_(transition_matrix = TM, states = states)
+  define_strategy_(transition = TM, states = states)
 }
 
 #' Load Data From a Folder Into an Environment
@@ -1021,18 +1035,19 @@ save_outputs <- function(outputs, output_dir, overwrite) {
     save_graph(this_plot, output_dir, this_file)
   }
   
-  base_model <- get_base_model(outputs$model_runs)
+  lowest_model <- get_lowest_model(outputs$model_runs)
   
   ## plots about differences between models
   if (options()$heemod.verbose) message("** Generating plots with model differences...")
-  for(this_model in setdiff(model_names, base_model)){
+  for(this_model in setdiff(model_names, lowest_model)){
     this_plot <- plot(outputs$dsa, type = "diff", model = this_model)
-    this_file <- paste("dsa", this_model, "vs", base_model, sep = "_")
+    this_file <- paste("dsa", this_model, "vs", lowest_model, sep = "_")
+
     save_graph(this_plot, output_dir, this_file)
     
     if(!is.null(outputs$psa)){
       this_plot <- plot(outputs$psa, model = this_model)
-      this_file <- paste("psa", this_model, "vs", base_model, sep = "_")
+      this_file <- paste("psa", this_model, "vs", lowest_model, sep = "_")
       save_graph(this_plot, output_dir, this_file)
     }
   }
