@@ -67,7 +67,8 @@ update.run_model <- function(object, newdata, ...) {
     suppressMessages({
       list_res <- c(
         list_res,
-        list(eval_model_newdata(object, model = n, newdata = newdata))
+        list(eval_model_newdata(object, model = n, 
+                                newdata = newdata))
       )
     })
   }
@@ -222,7 +223,7 @@ summary.updated_models <- function(object, ...) {
                  ".dcost", ".deffect", 
                  ".icer"),
       labels = c("Cost", "Effect",
-                 "\u0394 Cost", "\u0394 Effect",
+                 "Cost Diff.", "Effect Diff.",
                  "Icer")
     )
   
