@@ -4,34 +4,34 @@ param <- define_parameters(
   r = .05
 )
 mod1 <- define_strategy(
-    transition_matrix = define_transition(
-      C, p1,
-      p2, C
-    ),
-    define_state(
-      cost = discount(543, r),
-      ly = 1
-    ),
-    define_state(
-      cost = discount(432, r),
-      ly = .5
-    )
+  transition = define_transition(
+    C, p1,
+    p2, C
+  ),
+  define_state(
+    cost = discount(543, r),
+    ly = 1
+  ),
+  define_state(
+    cost = discount(432, r),
+    ly = .5
   )
+)
 
 mod2 <- define_strategy(
-    transition_matrix = define_transition(
-      C, p1,
-      p2, C
-    ),
-    define_state(
-      cost = 789,
-      ly = 1
-    ),
-    define_state(
-      cost = 456,
-      ly = .8
-    )
+  transition = define_transition(
+    C, p1,
+    p2, C
+  ),
+  define_state(
+    cost = 789,
+    ly = 1
+  ),
+  define_state(
+    cost = 456,
+    ly = .8
   )
+)
 
 res2 <- run_model(
   mod1, mod2,
