@@ -4,7 +4,7 @@ test_that(
   "Demographic analysis", {
     mod1 <-
       define_strategy(
-        transition_matrix = define_transition(
+        transition = define_transition(
           .4, .6,
           .1, .9
         ),
@@ -20,7 +20,7 @@ test_that(
     
     mod2 <-
       define_strategy(
-        transition_matrix = define_transition(
+        transition = define_transition(
           .5, .5,
           .1, .9
         ),
@@ -49,22 +49,22 @@ test_that(
     
     # generating table with demographic data
     new_tab <- data.frame(
-      age_init = 40:80
+      age_init = 40:45
     )
     set.seed(1)
     new_tab2 <- data.frame(
-      age_init = 40:80,
-      .weights = runif(41)
+      age_init = 40:45,
+      .weights = runif(6)
     )
     
     x <- update(res, newdata = new_tab2)
+    
     plot(x, type = "counts", model = 1)
     expect_message(update(res, newdata = new_tab))
     
     expect_output(
       print(x),
-      "       Cost   Effect      ICER
-I -28996.37 2.403762 -12062.91",
+      "-20268.86      1.66937 -12141.62",
       fixed = TRUE
     )
   })
@@ -74,7 +74,7 @@ test_that(
   "Heterogeneity analysis", {
     mod1 <-
       define_strategy(
-        transition_matrix = define_transition(
+        transition = define_transition(
           .5, .5,
           .1, .9
         ),
@@ -91,7 +91,7 @@ test_that(
     
     mod2 <-
       define_strategy(
-        transition_matrix = define_transition(
+        transition = define_transition(
           .5, .5,
           .1, .9
         ),
@@ -131,9 +131,6 @@ test_that(
     plot(ndt, model = 1, type = "cost")
     plot(ndt, model = 1, type = "effect")
     
-    expect_error(
-      plot(ndt, model = "II")
-    )
     expect_error(
       update(mod1, newdata = new_tab)
     )
